@@ -1,15 +1,7 @@
 """Presenters package - formats attachment objects for output."""
 
 # Import all presenter modules to register them
-from . import text
-from . import visual
-from . import data
-from . import metadata
+from . import data, metadata, text, visual
 
 # Re-export commonly used functions if needed
-__all__ = [
-    'text',
-    'visual',
-    'data', 
-    'metadata'
-] 
\ No newline at end of file
+__all__ = ["text", "visual", "data", "metadata"]
