@@ -2,6 +2,4 @@
 
 from .info import *
 
-__all__ = [
-    'metadata'
-] 
\ No newline at end of file
+__all__ = ["metadata"]
