@@ -3,16 +3,13 @@
 from .markdown import *
 from .plain import *
 from .structured import *
-from .ocr import *
 
 __all__ = [
     # Markdown presenters
-    'markdown',
-    # Plain text presenters  
-    'text',
+    "markdown",
+    # Plain text presenters
+    "text",
     # Structured text presenters
-    'csv',
-    'xml',
-    # OCR presenters
-    'ocr'
+    "csv",
+    "xml",
 ]
